/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWMEMORY_NAMESPACE_HPP__
#define __FWMEMORY_NAMESPACE_HPP__

/**
 * @brief       The namespace fwMemory contains tools to manage memory. Use for dump.
 * @namespace   fwMemory
 *
 * @date        2009-2011.
 *
 */
namespace fwMemory
{
}
#endif /* __FWMEMORY_NAMESPACE_HPP__ */
